@@ -52,7 +52,7 @@
 /**
  * go_gtk_button_build_with_stock:
  * @text: button label
- * @stock_id: id for stock icon
+ * @stock_id: icon name (or stock id)
  *
  * FROM : gedit
  * Creates a new GtkButton with custom label and stock image.
@@ -68,6 +68,9 @@ go_gtk_button_build_with_stock (char const *text, char const* stock_id)
 	if (gtk_stock_lookup (stock_id, &item))
 		gtk_button_set_image (GTK_BUTTON (button),
 			gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON));
+	else
+		gtk_button_set_image (GTK_BUTTON (button),
+				      gtk_image_new_from_icon_name (stock_id, GTK_ICON_SIZE_BUTTON));
 	return button;
 }
 
@@ -79,7 +82,7 @@ go_gtk_button_build_with_stock (char const *text, char const* stock_id)
  * FROM : gedit
  * Creates a new GtkButton with custom label and stock image.
  *
- * Deprecated: 09.6., use go_gtk_button_build_with_stock().
+ * Deprecated: 0.9.6., use go_gtk_button_build_with_stock().
  * Returns: (transfer full): newly created button
  **/
 GtkWidget*
@@ -139,7 +142,7 @@ apply_ui_from_file (GtkBuilder *gui, GsfInput *src, const char *uifile,
 		/*
 		 * This is sad, but see bugs 662503 and 662679.  Since
 		 * ui files can contain relative filenames we must use
-		 * the _file interface to load such files.  Do no
+		 * the _file interface to load such files.  Do not
 		 * compress such files for the time being.
 		 */
 		res = gtk_builder_add_from_file (gui, uifile, error);
@@ -175,7 +178,7 @@ apply_ui_from_file (GtkBuilder *gui, GsfInput *src, const char *uifile,
 **/
 GtkBuilder *
 go_gtk_builder_load (char const *uifile,
-		    char const *domain, GOCmdContext *gcc)
+		     char const *domain, GOCmdContext *gcc)
 {
 	GtkBuilder *gui;
 	GError *error = NULL;
@@ -221,6 +224,18 @@ go_gtk_builder_load (char const *uifile,
 	} else if (error)
 		g_error_free (error);
 
+	if (gui && go_debug_flag ("leaks")) {
+		GSList *l, *objs = gtk_builder_get_objects (gui);
+		for (l = objs; l; l = l->next) {
+			GObject *obj = l->data;
+			/* Darn -- cannot access object name! */
+			char *name = g_strdup_printf ("Anonymous from %s", uifile);
+			go_debug_check_finalized (obj, name);
+			g_free (name);
+		}
+		g_slist_free (objs);
+	}
+
 	return gui;
 }
 
@@ -274,12 +289,14 @@ go_gtk_builder_new (char const *uifile,
 **/
 GtkBuilder *
 go_gtk_builder_load_internal (char const *uifile,
-			     char const *domain, GOCmdContext *gcc)
+			      char const *domain, GOCmdContext *gcc)
 {
 	char *f;
 	GtkBuilder *res;
 
-	if (g_path_is_absolute (uifile) || strncmp (uifile, "res:", 4) == 0)
+	if (g_path_is_absolute (uifile) ||
+	    strncmp (uifile, "res:", 4) == 0 ||
+	    strncmp (uifile, "data:", 5) == 0)
 		return go_gtk_builder_load (uifile, domain, gcc);
 
 	f = g_build_filename (go_sys_data_dir (), "ui", uifile, NULL);
@@ -289,35 +306,6 @@ go_gtk_builder_load_internal (char const *uifile,
 	return res;
 }
 
-/**
- * go_gtk_builder_new_internal:
- * @uifile: the name of the file load
- * @domain: the translation domain
- * @gcc: #GOCmdContext
- *
- * Simple utility to open ui files
- *
- * Deprecated: 0.9.6, use go_gtk_builder_load_internal().
- * Returns: (transfer full): a new #GtkBuilder or NULL
- *
- * Variant of go_gtk_builder_new that searchs goffice directories
- * for files.
- * @uifile should be one of these:
- *
- * res:NAME  -- data from resource manager
- * data:DATA -- data right here
- * filename  -- data from local file
- *
- * Data may be compressed, regardless of source.
-**/
-GtkBuilder *
-go_gtk_builder_new_internal (char const *uifile,
-			     char const *domain, GOCmdContext *gcc)
-{
-	return go_gtk_builder_load_internal (uifile, domain, gcc);
-}
-
-
 /**
  * go_gtk_builder_signal_connect:
  * @gui: #GtkBuilder
@@ -823,7 +811,7 @@ update_preview_cb (GtkFileChooser *chooser)
 			GdkScreen *screen = gtk_widget_get_screen (GTK_WIDGET (chooser));
 			buf = go_pixbuf_new_from_pixbuf (gtk_icon_theme_load_icon
 						(gtk_icon_theme_get_for_screen (screen),
-						 "unknown_image", 100, 100, NULL));
+						 "unknown_image", 100, 0, NULL));
 			dummy = buf != NULL;
 		}
 
@@ -1594,3 +1582,54 @@ go_gtk_url_show (gchar const *url, GdkScreen *screen)
 	gtk_show_uri (screen, url, GDK_CURRENT_TIME, &error);
 	return error;
 }
+
+/**
+ * go_gtk_widget_render_icon_pixbuf:
+ * @widget: a mapped widget determining the screen targeted
+ * @icon_name: the name of the icon to render
+ * @size: the symbolic size desired.
+ *
+ * This function works as gtk_widget_render_icon_pixbuf except that it takes
+ * an icon name, not a stock id.
+ *
+ * Returns: (transfer full): A #GdkPixbuf.
+ **/
+GdkPixbuf *
+go_gtk_widget_render_icon_pixbuf (GtkWidget   *widget,
+				  const gchar *icon_name,
+				  GtkIconSize  size)
+{
+	GdkScreen *screen;
+	GtkIconTheme *theme;
+	int pixels;
+	GdkPixbuf *res;
+
+	/* The widget really ought to be mapped.  */
+	screen = gtk_widget_has_screen (widget)
+		? gtk_widget_get_screen (widget)
+		: gdk_screen_get_default ();
+	theme = gtk_icon_theme_get_for_screen (screen);
+
+	switch (size) {
+	default:
+	case GTK_ICON_SIZE_MENU:
+	case GTK_ICON_SIZE_SMALL_TOOLBAR:
+	case GTK_ICON_SIZE_BUTTON:
+		pixels = 16;
+		break;
+	case GTK_ICON_SIZE_LARGE_TOOLBAR:
+	case GTK_ICON_SIZE_DND:
+		pixels = 24;
+		break;
+	case GTK_ICON_SIZE_DIALOG:
+		pixels = 48;
+		break;
+	}
+
+	res = gtk_icon_theme_load_icon (theme, icon_name, pixels, 0, NULL);
+
+	if (res && go_debug_flag ("leaks"))
+		go_debug_check_finalized (res, icon_name);
+
+	return res;
+}
