@@ -59,6 +59,35 @@
 
 /* ------------------------------------------------------------------------- */
 
+static COMPLEX *
+SUFFIX(go_complex_dup) (COMPLEX *src)
+{
+	return g_memdup (src, sizeof (*src));
+}
+
+#define MAKE_BOXED_TYPE(id,name)					\
+GType									\
+id (void)								\
+{									\
+	static GType t = 0;						\
+									\
+	if (t == 0)							\
+		t = g_boxed_type_register_static			\
+			(name,						\
+			 (GBoxedCopyFunc)SUFFIX(go_complex_dup),	\
+			 (GBoxedFreeFunc)g_free);			\
+	return t;							\
+}
+
+
+#ifdef LONG_DOUBLE_VERSION
+MAKE_BOXED_TYPE(go_complexl_get_type, "GOComplexl")
+#else
+MAKE_BOXED_TYPE(go_complex_get_type, "GOComplex")
+#endif
+
+/* ------------------------------------------------------------------------- */
+
 char *
 SUFFIX(go_complex_to_string) (COMPLEX const *src, char const *reformat,
 		   char const *imformat, char imunit)
@@ -242,6 +271,20 @@ SUFFIX(go_complex_div) (COMPLEX *dst, COMPLEX const *a, COMPLEX const *b)
 void
 SUFFIX(go_complex_sqrt) (COMPLEX *dst, COMPLEX const *src)
 {
+	if (src->re < 0 && -src->re > SUFFIX(fabs)(src->im)) {
+		// Near the negative axis we do not want to squeeze
+		// angle/pi against +-1.
+		COMPLEX msrc, r;
+		msrc.re = - src->re;
+		msrc.im = - src->im;
+		SUFFIX(go_complex_sqrt) (&r, &msrc);
+		if (src->im >= 0)
+			SUFFIX(go_complex_init) (dst, 0 - r.im, r.re);
+		else
+			SUFFIX(go_complex_init) (dst, r.im, 0 - r.re);
+		return;
+	}
+
 	SUFFIX(go_complex_from_polar_pi)
 		(dst,
 		 SUFFIX(sqrt) (SUFFIX(go_complex_mod) (src)),
@@ -322,10 +365,14 @@ SUFFIX(mulmod1) (SUFFIX(GOQuad) *dst, SUFFIX(GOQuad) const *qa_, DOUBLE b)
 }
 
 void
-SUFFIX(go_complex_pow) (COMPLEX *dst, COMPLEX const *a, COMPLEX const *b)
+SUFFIX(go_complex_powx) (COMPLEX *dst, DOUBLE *e,
+			 COMPLEX const *a, COMPLEX const *b)
 {
+	if (e)
+		*e = 0;
+
 	if (b->im == 0) {
-		if (SUFFIX(go_complex_real_p) (a) && a->re >= 0) {
+		if (!e && SUFFIX(go_complex_real_p) (a) && a->re >= 0) {
 			SUFFIX(go_complex_init) (dst, SUFFIX(pow) (a->re, b->re), 0);
 			return;
 		}
@@ -347,8 +394,7 @@ SUFFIX(go_complex_pow) (COMPLEX *dst, COMPLEX const *a, COMPLEX const *b)
 	}
 
 	{
-		DOUBLE e1, e2;
-		int e;
+		DOUBLE e1, e2, er;
 		SUFFIX(GOQuad) qr, qa, qb, qarg, qrr, qra;
 		void *state = SUFFIX(go_quad_start) ();
 
@@ -366,9 +412,14 @@ SUFFIX(go_complex_pow) (COMPLEX *dst, COMPLEX const *a, COMPLEX const *b)
 		SUFFIX(go_quad_mul) (&qb, &qb, &SUFFIX(go_quad_pi));
 		SUFFIX(go_quad_exp) (&qb, &e2, &qb);
 		SUFFIX(go_quad_mul) (&qrr, &qa, &qb);
-		e = CLAMP (e1 + e2, G_MININT, G_MAXINT);
-		qrr.h = SUFFIX(ldexp) (qrr.h, e);
-		qrr.l = SUFFIX(ldexp) (qrr.l, e);
+		er = e1 + e2;
+		if (e)
+			*e = er;
+		else {
+			er = CLAMP (er, G_MININT, G_MAXINT);
+			qrr.h = SUFFIX(ldexp) (qrr.h, er);
+			qrr.l = SUFFIX(ldexp) (qrr.l, er);
+		}
 
 		/* Compute result angle.  */
 		SUFFIX(go_quad_log) (&qa, &qr);
@@ -392,6 +443,12 @@ SUFFIX(go_complex_pow) (COMPLEX *dst, COMPLEX const *a, COMPLEX const *b)
 	}
 }
 
+void
+SUFFIX(go_complex_pow) (COMPLEX *dst, COMPLEX const *a, COMPLEX const *b)
+{
+	SUFFIX(go_complex_powx) (dst, NULL, a, b);
+}
+
 /* ------------------------------------------------------------------------- */
 
 void SUFFIX(go_complex_init) (COMPLEX *dst, DOUBLE re, DOUBLE im)
@@ -500,14 +557,19 @@ void SUFFIX(go_complex_exp) (COMPLEX *dst, COMPLEX const *src)
 
 void SUFFIX(go_complex_ln) (COMPLEX *dst, COMPLEX const *src)
 {
-	SUFFIX(go_complex_init) (dst,
-		SUFFIX(log) (SUFFIX(go_complex_mod) (src)),
-		SUFFIX(go_complex_angle) (src));
+	DOUBLE x = SUFFIX(fabs) (src->re);
+	DOUBLE y = SUFFIX(fabs) (src->im);
+	DOUBLE lm = x > y
+		? SUFFIX(log) (x) + 0.5 * SUFFIX(log1p) ((y / x) * (y / x))
+		: SUFFIX(log) (y) + 0.5 * SUFFIX(log1p) ((x / y) * (x / y));
+	DOUBLE a = SUFFIX(go_complex_angle) (src);
+
+	SUFFIX(go_complex_init) (dst, lm, a);
 }
 
 /* ------------------------------------------------------------------------- */
 
-void SUFFIX(go_complex_sin) ( COMPLEX *dst,  COMPLEX const *src)
+void SUFFIX(go_complex_sin) (COMPLEX *dst, COMPLEX const *src)
 {
 	SUFFIX(go_complex_init) (dst,
 		SUFFIX(sin) (src->re) * SUFFIX(cosh) (src->im),
@@ -516,7 +578,7 @@ void SUFFIX(go_complex_sin) ( COMPLEX *dst,  COMPLEX const *src)
 
 /* ------------------------------------------------------------------------- */
 
-void SUFFIX(go_complex_cos) (COMPLEX *dst,  COMPLEX const *src)
+void SUFFIX(go_complex_cos) (COMPLEX *dst, COMPLEX const *src)
 {
 	SUFFIX(go_complex_init) (dst,
 		SUFFIX(cos) (src->re) * SUFFIX(cosh) (src->im),
@@ -527,11 +589,29 @@ void SUFFIX(go_complex_cos) (COMPLEX *dst,  COMPLEX const *src)
 
 void SUFFIX(go_complex_tan) (COMPLEX *dst, COMPLEX const *src)
 {
-	COMPLEX s, c;
+	DOUBLE R = src->re, I = src->im;
+	DOUBLE sr = SUFFIX(sin) (R);
+	DOUBLE cr = SUFFIX(cos) (R);
 
-	SUFFIX(go_complex_sin) (&s, src);
-	SUFFIX(go_complex_cos) (&c, src);
-	SUFFIX(go_complex_div) (dst, &s, &c);
+	// Code here inspired by gsl, but doesn't follow it.
+
+	if (SUFFIX(fabs) (I) < 1) {
+		DOUBLE shi = SUFFIX(sinh) (I);
+		DOUBLE D = cr * cr + shi * shi;
+
+		SUFFIX(go_complex_init) (dst,
+					 sr * cr / D,
+					 0.5 * SUFFIX(sinh) (2 * I) / D);
+	} else {
+		DOUBLE u = SUFFIX(exp) (-SUFFIX(fabs)(I));
+		DOUBLE C = 2 * u / (1 - u * u);
+		DOUBLE S = C * C;
+		DOUBLE D = 1 + cr * cr * S;
+		DOUBLE T = 1.0 / SUFFIX(tanh) (SUFFIX(fabs) (I));
+		SUFFIX(go_complex_init) (dst,
+					 sr * cr * S / D,
+					 (I < 0 ? -T : T) / D);
+	}
 }
 
 /* ------------------------------------------------------------------------- */
