@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gog-color.c :
+ * go-color.c :
  *
  * Copyright (C) 2003-2004 Jody Goldberg (jody@gnome.org)
  *
@@ -21,20 +21,14 @@
  */
 
 #include <goffice/goffice-config.h>
-#include "go-color.h"
+#include <goffice/goffice.h>
 
 #include <stdio.h>
 
-/**
- * GONamedColor:
- * @color: the color.
- * @name: english name - eg. "white".
- **/
-
 /**
  * go_color_from_str :
- * @str :
- * @res :
+ * @str:
+ * @res:
  *
  * Returns: TRUE if @str can be parsed as a color of the form R:G:B:A and the
  * 	result is stored in @res.
